==> xmonad-extras-0.17.2-53-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-K5lfQFi5WDrCesQkZJ35As
key:                  xmonad-extras-0.17.2-K5lfQFi5WDrCesQkZJ35As
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  b42dd97764537de81cf6ecad026f323f
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-K5lfQFi5WDrCesQkZJ35As
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.1-1urctfXT5qM4DuzWl1Z5wm
    hint-0.9.0.8-4HMAVjMmDhAG9gfF7pluUZ
    libmpd-0.10.0.1-JZVj8f8QnCaHykuKOIOALq mtl-2.2.2
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-8KSDSyJRi3D35avx2QBk2o
    xmonad-contrib-0.18.1-JR7MWCKNVJq8K5GWpJQFAI

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-extras-0.17.2-54-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-KEopflYaqcLF454HABfK45
key:                  xmonad-extras-0.17.2-KEopflYaqcLF454HABfK45
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  ff57c1de17958dee82f5ee21b2d5e799
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-KEopflYaqcLF454HABfK45
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.1-6X5FoT1K4bX8kzalTjxEF4
    hint-0.9.0.8-4HMAVjMmDhAG9gfF7pluUZ
    libmpd-0.10.0.1-JZVj8f8QnCaHykuKOIOALq mtl-2.2.2
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-8KSDSyJRi3D35avx2QBk2o
    xmonad-contrib-0.18.1-JR7MWCKNVJq8K5GWpJQFAI

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
